@@ -2,7 +2,10 @@
 # There are create, read, update and delete calls for all of the three basic elements in OpenStreetMap (''Nodes'', ''Ways'' and ''Relations''). These calls are very similar except for the payload and a few special error messages so they are documented only once.
 
 
-## Create: `PUT /api/0.6/[node|way|relation]/create` ----
+## Create: `POST /api/0.6/[nodes|ways|relations]` ----
+#
+# Also available at `PUT /api/0.6/[node|way|relation]/create` (deprecated)
+#
 # Creates a new element of the specified type. Note that the entire request should be wrapped in a <code><osm>...</osm></code> element.
 #
 # A Node:
@@ -144,8 +147,8 @@ osm_create_object <- function(x, changeset_id) {
 
 
   req <- osmapi_request(authenticate = TRUE)
-  req <- httr2::req_method(req, "PUT")
-  req <- httr2::req_url_path_append(req, osm_type, "create")
+  req <- httr2::req_method(req, "POST")
+  req <- httr2::req_url_path_append(req, paste0(osm_type, "s"))
   req <- httr2::req_body_file(req, path = path)
 
   resp <- httr2::req_perform(req)
@@ -179,10 +182,10 @@ osm_create_object <- function(x, changeset_id) {
 # JSON representing the element, wrapped in an <code><json></code> element:
 # <syntaxhighlight lang="json">
 # {
-#  "version": "0.6",
-#  "elements": [
-#   {"type": "node", "id": 4326396331, "lat": 31.9016302, "lon": -81.5990471, "timestamp": "2016-07-31T00:08:11Z", "version": 2, "changeset": 41136027, "user": "maven149", "id": 136601}
-#  ]
+#   "version": "0.6",
+#   "elements": [
+#     {"type": "node", "id": 4326396331, "lat": 31.9016302, "lon": -81.5990471, "timestamp": "2016-07-31T00:08:11Z", "version": 2, "changeset": 41136027, "user": "maven149", "id": 136601}
+#   ]
 # }
 # </syntaxhighlight>
 #
@@ -406,7 +409,7 @@ osm_update_object <- function(x, changeset_id) {
 # </osm>
 # </syntaxhighlight>
 #
-# Where the node ID in the XML must match the ID in the URL, the version must match the version of the element you downloaded and the changeset must match the ID of an open changeset owned by the current authenticated user. It is allowed, but not necessary, to have tags on the element except for lat/long tags which are required, without lat+lon the server gives 400 Bad request.
+# Where the node ID in the XML must match the ID in the URL, the version must match the version of the element you downloaded and the changeset must match the ID of an open changeset owned by the current authenticated user. It is allowed, but not necessary, to have tags on the element except for lat/lon tags which are required, without lat+lon the server gives 400 Bad request.
 #
 ### Response ----
 # Returns the new version number with a content type of `text/plain`.
@@ -434,8 +437,8 @@ osm_update_object <- function(x, changeset_id) {
 # : When a node is still member of a relation: `Node #{id} is still used by relation #{relation.id}.`
 # : When a way is still member of a relation: `Way #{id} still used by relation #{relation.id}.`
 # : When a relation is still member of another relation: `The relation #{id} is used in relation #{relation.id}.`
-# :
-# : Note when returned as a result of a OsmChange upload operation the error messages contain a spurious plural "s" as in "... still used by ways ...", "... still used by relations ..." even when only 1 way or relation id is returned, as this implies multiple ids can be returned if the deleted object was/is a member of multiple parent objects, these ids are seperated by commas.
+# : Note when returned as a result of a OsmChange upload operation the error messages contain a spurious plural "s" as in "... still used by ways ...", "... still used by relations ..." even when only 1 way or relation id is returned, as this implies multiple ids can be returned if the deleted object was/is a member of multiple parent objects, these ids are separated by commas. Note that the Rails API and CGIMAP have inconsistent behaviour wrt the plural "s".
+#
 # ; HTTP status code 429 (Too many requests)
 # : When the request has been blocked due to rate limiting
 #
@@ -455,7 +458,7 @@ osm_update_object <- function(x, changeset_id) {
 #' @details
 #' The version must match the version of the element you downloaded and the changeset must match the `id` of an open
 #' changeset owned by the current authenticated user. It is allowed, but not necessary, to have tags on the element
-#' except for lat/long which are required for nodes, without lat+lon the server gives 400 Bad request.
+#' except for lat/lon which are required for nodes, without lat+lon the server gives 400 Bad request.
 #'
 #' If `x` is a data.frame, the columns `type`, `id`, `version` and `changeset` must be present + `lat` and `lon` for
 #' nodes. For the xml format, see the
